This function calculates a precise numerical estimate of alpha based by matching the number of observed interesting panels to the corresponding value of alpha.

estimate_alpha_numeric(Zc, c = m0/K, m0 = 19, K = 30)

Arguments

Zc

Average number of panels with at least c selections

c

The number of selections a panel must have to be interesting (can be non-integer)

m0

The number of null panels in the lineup

K

The total number of null panel selections (or, in a Rorschach lineup, the total number of evaluations)

Value

a data frame with list-columns for alpha, optimized sum of squared error, counts (as returned from optim), convergence,

Examples

res <- estimate_alpha_numeric(5, c = 1, m0 = 19, K = 30)
res$alpha
#> [1] 0.09625815