This function returns panel selection counts simulated from the Dirichlet- Multinomial model; that is, the result is a \(m \times N\) matrix of panel selection counts.

rVis(N = 50, K = 22, m = 20, alpha, scenario = 3)

Arguments

N

Number of lineups to simulate

K

The total number of null panel selections (or, in a Rorschach lineup, the total number of evaluations)

m

The number of panels in the lineup

alpha

The (scalar) symmetric Dirichlet parameter which is related to the number of interesting panels

scenario

which lineup administration is used? scenario 1 and 3 are implemented

Value

Matrix of dimension m by N

Examples

rVis(alpha = .5, m = 20, K = 30, N = 5, scenario = 3)
#>       [,1] [,2] [,3] [,4] [,5]
#>  [1,]    0    0    0    0    0
#>  [2,]    4    5    6    4    5
#>  [3,]    0    0    0    0    0
#>  [4,]    3    4    4    2    5
#>  [5,]    2    1    2    0    1
#>  [6,]    0    0    0    0    0
#>  [7,]    1    0    0    0    0
#>  [8,]    0    0    0    0    0
#>  [9,]    2    2    1    2    3
#> [10,]    5    4    1    0    5
#> [11,]    0    0    1    0    0
#> [12,]    2    0    2    2    1
#> [13,]    1    1    1    1    1
#> [14,]    1    1    1    2    1
#> [15,]    0    0    0    0    0
#> [16,]    2    4    3    0    2
#> [17,]    0    0    1    0    1
#> [18,]    4    3    3    7    1
#> [19,]    1    2    1    4    3
#> [20,]    2    3    3    6    1
rVis(alpha = .5, m = 20, K = 30, N = 5, scenario = 1)
#>       [,1] [,2] [,3] [,4] [,5]
#>  [1,]    4    0    2    0    0
#>  [2,]    0    0    2    0    1
#>  [3,]    1    0    4    0    0
#>  [4,]    0    0    0    0    0
#>  [5,]    6    0    3    0    0
#>  [6,]    0    0    0    0   15
#>  [7,]   15    1    0    0    0
#>  [8,]    1   17    0    0    0
#>  [9,]    0    0    0    0    6
#> [10,]    0    0    0    2    0
#> [11,]    0    0    3    0    0
#> [12,]    0    0    0    0    0
#> [13,]    1    0    0    0    3
#> [14,]    0    0    1    1    0
#> [15,]    0    4    0    0    0
#> [16,]    0    1    0    3    4
#> [17,]    0    0    0    3    0
#> [18,]    2    0   14    0    1
#> [19,]    0    7    0   15    0
#> [20,]    0    0    1    6    0