dV(x, K, m, scenario, type = "numeric")vector of the number of picks of the data plot out of K evaluations
number of evaluations
size of the lineup
which scenario should be used? 1, 2, or 3?
one of "mpfr" or "numeric". Should the result be in arbitrary numeric length or be a numeric? Internally the Rmpfr package is used to get maximal precision.
dV(0:5, 5, m=2, scenario=3)
#> Warning: `dV()` was deprecated in vinference 1.0.0.
#> ℹ Please use `dVis()` instead.
#> Loading required namespace: Rmpfr
#> 0 1 2 3 4 5
#> 0.1212987 0.1703680 0.2083333 0.2083333 0.1703680 0.1212987
## compare to
dVsim(0:5, 5, m=2, scenario=3)
#> Warning: `dVsim()` was deprecated in vinference 1.0.0.
#> ℹ Please use `dVis()` instead.
#> x scenario3 binom
#> 1 0 0.1237 0.03125
#> 2 1 0.1658 0.15625
#> 3 2 0.2071 0.31250
#> 4 3 0.2075 0.31250
#> 5 4 0.1664 0.15625
#> 6 5 0.1295 0.03125
require(ggplot2)
#> Loading required package: ggplot2
## probabilities can be computed without numeric loss for K=50:
K <- 50
print(qplot(0:K, dV(0:K, K, m=20, scenario=3)));
#> Warning: `qplot()` was deprecated in ggplot2 3.4.0.
print(sum(dV(0:K, K, m=20, scenario=3)));
#> [1] 1