R/estimate_alpha.R
estimate_alpha_numeric.RdThis function calculates a precise numerical estimate of alpha based by matching the number of observed interesting panels to the corresponding value of alpha.
estimate_alpha_numeric(Zc, c = m0/K, m0 = 19, K = 30)a data frame with list-columns for alpha, optimized sum of squared error, counts (as returned from optim), convergence,
res <- estimate_alpha_numeric(5, c = 1, m0 = 19, K = 30)
res$alpha
#> [1] 0.09625815