R/estimate_alpha.R
observed_band.RdThis function adds a band to assist in the visual estimation of alpha from evaluated lineups.
observed_band(obs, limits, c = m0/K, m0 = 19, K = 30)Observed number of "c-interesting" panels (panels with at least c selections). If NA, the line is omitted.
Lower and upper bounds for number of panels. If NA, the bands are omitted.
The number of selections a panel must have to be interesting (can be non-integer)
The number of null panels in the lineup
The total number of null panel selections (or, in a Rorschach lineup, the total number of evaluations)
estimate_alpha_visual() + observed_band(obs = NA, limits = c(5, 7))
#> Warning: log-10 transformation introduced infinite values.
estimate_alpha_visual() + observed_band(obs = 6, limits = NA)
#> Warning: log-10 transformation introduced infinite values.
estimate_alpha_visual(c = 1, m0 = 19, K = 50) +
observed_band(obs = 6, limits = c(4, 8), c = 1, m0 = 19, K = 50)
#> Warning: log-10 transformation introduced infinite values.
#> Warning: log-10 transformation introduced infinite values.