pV(x, K, m, scenario, type = "numeric")vector of the number of picks of the data plot out of K evaluations
number of evaluations
size of the lineup
which scenario should be used? 1, 2, or 3?
one of "mpfr" or "numeric". Should the result be in arbitrary numeric length or be a numeric? Internally the Rmpfr package is used to get maximal precision.
pV(0:5, 5, m=3, scenario=3)
#> Warning: `pV()` was deprecated in vinference 1.0.0.
#> ℹ Please use `pVis()` instead.
#> 0 1 2 3 4 5
#> 1.00000000 0.77178555 0.50523654 0.26388889 0.10185185 0.02390384