R/estimate_alpha.R
sim_interesting_panels.RdSimulate the number of c-interesting panels for a lineup experiment
sim_interesting_panels(
alphas = 10^seq(-2, 2, 0.05),
c = m0/K,
m0 = 19,
K = 30,
N_points = 10,
avg_n_sims = 10
)Numeric vector of alpha values to conduct simulations for
The number of selections a panel must have to be interesting (can be non-integer)
The number of null panels in the lineup
The total number of null panel selections (or, in a Rorschach lineup, the total number of evaluations)
The number of points to simulate for each value of alpha
The number of simulations to average to get a single point value. Averaging several simulations reduces the visual noise but also decreases the separation between possible values for a more continuous appearance.
sim_interesting_panels()
#> # A tibble: 810 × 3
#> # Groups: alpha [81]
#> alpha point_num n_interesting
#> <dbl> <dbl> <dbl>
#> 1 0.01 0 1
#> 2 0.01 1 1
#> 3 0.01 2 1
#> 4 0.01 3 1
#> 5 0.01 4 1
#> 6 0.01 5 1
#> 7 0.01 6 1
#> 8 0.01 7 1
#> 9 0.01 8 1
#> 10 0.01 9 1
#> # ℹ 800 more rows